@@ -157,11 +157,6 @@ class AuthCryptoSign(object):
                 raise ValueError(
                     "Must provide '{}' for cryptosign".format(key)
                 )
-        for key in kw.get('authextra', dict()):
-            if key not in ['pubkey']:
-                raise ValueError(
-                    "Unexpected key '{}' in 'authextra'".format(key)
-                )
 
         from autobahn.wamp.cryptosign import SigningKey
         self._privkey = SigningKey.from_key_bytes(
@@ -579,7 +574,7 @@ def generate_wcs(length=14):
     :rtype: bytes
     """
     assert(type(length) == int)
-    return "".join([random.choice(WCS_SECRET_CHARSET) for _ in range(length)]).encode('ascii')
+    return "".join(random.choice(WCS_SECRET_CHARSET) for _ in range(length)).encode('ascii')
 
 
 @public
